@@ -19,11 +19,11 @@ Lingua::Conjunction - Convert lists into simple linguistic conjunctions
 
 =head1 VERSION
 
-Version 2.5
+Version 2.6
 
 =cut
 
-our $VERSION = '2.5';
+our $VERSION = '2.6';
 
 =head1 SYNOPSIS
 
@@ -45,6 +45,7 @@ and an updated version will be released.
 
 my %language = (
 	'af' => { sep => ',', alt => ';', pen => 1, con => 'en',  dis => 'of' },
+	'br' => { sep => ',', alt => ';', pen => 0, con => 'ha',  dis => 'ou' },	# Breton - 'and' is 'ha'
 	'da' => { sep => ',', alt => ';', pen => 1, con => 'og',  dis => 'eller' },
 	'de' => { sep => ',', alt => ';', pen => 1, con => 'und', dis => 'oder' },
 	'en' => { sep => ',', alt => ';', pen => 1, con => 'and', dis => 'or' },
@@ -79,8 +80,10 @@ converts a list into a properly punctuated text string.
 You can cause C<conjunction> to use the connectives of other languages, by
 calling the appropriate subroutine:
 
-    Lingua::Conjunction->lang('en');   # use 'and'
-    Lingua::Conjunction->lang('es');   # use 'y'
+    use Lingua::Conjunction;
+
+    Lingua::Conjunction->lang('en');	# use 'and'
+    Lingua::Conjunction->lang('es');	# use 'y'
     Lingua::Conjunction->lang();	# Tries to determine your language, otherwise falls back to 'en'
 
 Supported languages in this version are
@@ -110,14 +113,14 @@ You can also set connectives individually:
 =cut
 
 sub conjunction {
-	# See List::ToHumanString
+	# TODO: see List::ToHumanString
 	my @list = grep defined && /\S/, @_;
 
 	return if(scalar(@list) == 0);
 	return $list[0] if(scalar(@list) == 1);
-	return join(" $punct{$list_type} ", @list) if(scalar(@list) == 2);
+	return join(" $punct{$list_type} ", @list) if((scalar(@list) == 2) && !(grep /$punct{sep}/, @list));
 
-	if ( $punct{pen} ) {
+	if($punct{pen}) {
 		return join "$punct{sep} ", @list[ 0 .. $#list - 1 ],
 		  "$punct{$list_type} $list[-1]",
 		  unless grep /$punct{sep}/, @list;
@@ -297,7 +300,7 @@ Damian Conway <damian@conway.org>
 
 =head1 MAINTAINER
 
-    2021-present	Maintained by Nigel Horne, C<< <njh at bandsman.co.uk> >>
+2021-present	Maintained by Nigel Horne, C<< <njh at bandsman.co.uk> >>
 
 =head1 CONTRIBUTORS
 
@@ -351,18 +354,10 @@ L<https://metacpan.org/release/Lingua-Conjunction>
 
 L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=Lingua-Conjunction>
 
-=item * CPANTS
-
-L<http://cpants.cpanauthors.org/dist/Lingua-Conjunction>
-
 =item * CPAN Testers' Matrix
 
 L<http://matrix.cpantesters.org/?dist=Lingua-Conjunction>
 
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Lingua-Conjunction>
-
 =item * CPAN Testers Dependencies
 
 L<http://deps.cpantesters.org/?module=Lingua::Conjunction>
@@ -384,7 +379,9 @@ This software is Copyright (c) 1999-2020 by Robert Rothenberg.
 
 This is free software, licensed under:
 
-  The Artistic License 2.0 (GPL Compatible)
+The Artistic License 2.0 (GPL Compatible)
+
+The current maintainer is Nigel Horne.
 
 =cut
 
